Module: Yapper::Configuration
- Included in:
- Yapper
- Defined in:
- lib/yapper/configuration.rb
Overview
Defines constants and methods related to configuration
Constant Summary collapse
- VALID_OPTIONS_KEYS =
An array of valid keys in the options hash when configuring a Yammer::API
[ :adapter, :endpoint, :api_path_prefix, :format, :gateway, :oauth_token, :proxy, :user_agent].freeze
- DEFAULT_ADAPTER =
The adapter that will be used to connect if none is set
:net_http- DEFAULT_ENDPOINT =
Note:
This is configurable in case you want to use HTTP instead of HTTPS, specify a different API version.
The endpoint that will be used to connect if none is set
'https://www.yammer.com/'.freeze
- DEFAULT_API_VERSION =
'v1'.freeze
- DEFAULT_API_PATH_PREFIX =
'api/'+DEFAULT_API_VERSION
- DEFAULT_FORMAT =
Note:
JSON is preferred over XML because it is more concise and faster to parse.
The response format appended to the path and sent in the ‘Accept’ header if none is set
:json- DEFAULT_OAUTH_TOKEN =
By default, don’t set a user oauth token
nil- DEFAULT_PROXY =
By default, don’t use a proxy server
nil- DEFAULT_USER_AGENT =
The value sent in the ‘User-Agent’ header if none is set
"Yammer Ruby Gem #{Yapper::VERSION}".freeze
- DEFAULT_GATEWAY =
nil
Class Method Summary collapse
-
.extended(base) ⇒ Object
When this module is extended, set all configuration options to their default values.
Instance Method Summary collapse
-
#configure {|_self| ... } ⇒ Object
Convenience method to allow configuration options to be set in a block.
-
#options ⇒ Object
Create a hash of options and their values.
-
#reset ⇒ Object
Reset all configuration options to defaults.
Class Method Details
.extended(base) ⇒ Object
When this module is extended, set all configuration options to their default values
49 50 51 |
# File 'lib/yapper/configuration.rb', line 49 def self.extended(base) base.reset end |
Instance Method Details
#configure {|_self| ... } ⇒ Object
Convenience method to allow configuration options to be set in a block
54 55 56 |
# File 'lib/yapper/configuration.rb', line 54 def configure yield self end |
#options ⇒ Object
Create a hash of options and their values
59 60 61 62 63 |
# File 'lib/yapper/configuration.rb', line 59 def = {} VALID_OPTIONS_KEYS.each{|k| [k] = send(k)} end |
#reset ⇒ Object
Reset all configuration options to defaults
66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/yapper/configuration.rb', line 66 def reset self.adapter = DEFAULT_ADAPTER self.endpoint = DEFAULT_ENDPOINT self.api_path_prefix = DEFAULT_API_PATH_PREFIX self.format = DEFAULT_FORMAT self.oauth_token = DEFAULT_OAUTH_TOKEN self.proxy = DEFAULT_PROXY self.user_agent = DEFAULT_USER_AGENT self.gateway = DEFAULT_GATEWAY self end |